@@ -2,7 +2,7 @@
 #
 #       cons.py
 #
-#       Copyright 2009-2016 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2019 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -19,16 +19,17 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
 
-import os, sys
+import os
+import sys
+import tempfile
 
 
-VERSION = "0.37.6"
+VERSION = "0.38.9"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
     IS_WIN_OS = True
     SZA_PATH = '"'+os.path.join(SHARE_PATH, "7za.exe")+'"'
-    TMP_FOLDER = os.path.join(os.environ['TEMP'], 'ct_tmp/')
     GLADE_PATH = os.path.join(SHARE_PATH, 'glade/')
     SPECS_PATH = os.path.join(SHARE_PATH, 'language-specs/')
     LOCALE_PATH = os.path.join(SHARE_PATH, 'locale/')
@@ -39,7 +40,6 @@ if sys.platform.startswith("win"):
 else:
     IS_WIN_OS = False
     SZA_PATH = "7za"
-    TMP_FOLDER = '/tmp/ct_tmp/'
     MODULES_PATH = os.path.dirname(os.path.realpath(__file__))
     CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config', 'cherrytree')
     if SHARE_PATH == os.path.dirname(MODULES_PATH):
@@ -55,6 +55,7 @@ else:
 CONFIG_PATH = os.path.join(CONFIG_DIR, 'config.cfg')
 LANG_PATH = os.path.join(CONFIG_DIR, 'lang')
 IMG_PATH = os.path.join(CONFIG_DIR, 'img_tmp.png')
+TMP_FOLDER = tempfile.mkdtemp()
 
 try:
     import appindicator
@@ -63,8 +64,8 @@ except: HAS_APPINDICATOR = False
 XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
 HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
 
-AVAILABLE_LANGS = ['default', 'cs', 'de', 'el', 'en', 'es', 'fr', 'hy', 'it', 'ja', 'lt', 'nl', 'pl', 'pt_BR', 'ru', 'sl', 'tr', 'uk', 'zh_CN']
-COLOR_48_LINK_WEBS = "#00004444ffff"
+AVAILABLE_LANGS = ['default', 'cs', 'de', 'el', 'en', 'es', 'fi', 'fr', 'hy', 'it', 'ja', 'lt', 'nl', 'pl', 'pt_BR', 'ru', 'sl', 'tr', 'uk', 'zh_CN']
+COLOR_48_LINK_WEBS = "#00008989ffff"
 COLOR_48_LINK_NODE = "#071c838e071c"
 COLOR_48_LINK_FILE = "#8b8b69691414"
 COLOR_48_LINK_FOLD = "#7f7f7f7f7f7f"
@@ -130,7 +131,7 @@ ANCHOR_CHAR = GLADE_PATH + 'anchor.png'
 FILE_CHAR = GLADE_PATH + 'file_icon.png'
 
 MIN_CT_DOC_SIZE = 10
-MAX_FILE_NAME_LEN = 150
+MAX_FILE_NAME_LEN = 142
 WHITE_SPACE_BETW_PIXB_AND_TEXT = 3
 GRID_SLIP_OFFSET = 3
 MAIN_WIN_TO_TEXT_WIN_NORMALIZER = 50
@@ -139,6 +140,8 @@ MAX_TOOLTIP_LINK_CHARS = 150
 TABLE_DEFAULT_COL_MIN = 40
 TABLE_DEFAULT_COL_MAX = 400
 SCROLL_MARGIN = 0.3
+TREE_DRAG_EDGE_PROX = 10
+TREE_DRAG_EDGE_SCROLL = 15
 
 CHAR_SPACE = " "
 CHAR_NEWLINE = "\n"
@@ -147,9 +150,6 @@ CHAR_CR = "\r"
 CHAR_TAB = "\t"
 CHARS_LISTNUM = ".)->"
 NUM_CHARS_LISTNUM = len(CHARS_LISTNUM)
-CHAR_LISTTODO = "☐"
-CHAR_LISTDONEOK= "☑"
-CHAR_LISTDONEFAIL= "☒"
 CHAR_TILDE = "~"
 CHAR_MINUS = "-"
 CHAR_DQUOTE = '"'
@@ -242,15 +242,16 @@ STOCKS_N_FILES = [
 'node_bullet', 'node_no_icon', CHERRY_BLACK, CHERRY_BLUE,
 CHERRY_CYAN, CHERRY_GREEN, CHERRY_GRAY, CHERRY_ORANGE,
 CHERRY_ORANGE_DARK, CHERRY_PURPLE, CHERRY_RED, CHERRY_SHERBERT,
-CHERRY_YELLOW, 'image_insert', 'image_edit', 'image_save',
+CHERRY_YELLOW, 'image_insert', 'screenshot_insert', 'image_edit', 'image_save',
 'table_insert', 'table_edit', 'table_save', 'codebox_insert',
 'codebox_edit', 'anchor_insert', 'anchor_edit', 'anchor',
 'insert', 'link_handle', 'link_website', 'cherry_edit',
 'list_bulleted', 'list_numbered', 'list_todo', 'node_name_header',
 'case_toggle', 'case_upper', 'case_lower', 'edit-delete',
-'edit-copy', 'edit-cut', 'edit-paste', 'find',
-'find_again', 'find_back', 'find_replace', 'color_background',
-'color_foreground', 'format-text-large', 'format-text-large2', 'format-text-large3',
+'edit-copy', 'edit-cut', 'edit-paste',
+'find', 'find_sel', 'find_selnsub', 'find_all','find_again', 'find_back', 
+'replace_sel', 'replace_selnsub', 'replace_all', 'find_replace', 'replace_again',
+'color_background', 'color_foreground', 'format-text-large', 'format-text-large2', 'format-text-large3',
 'format-text-small', 'format-text-subscript', 'format-text-superscript', 'format-text-monospace',
 'format-text-strikethrough', 'format-text-underline', 'format-text-bold', 'format-text-italic',
 'format_text_latest', 'format_text_clear', 'format_text',
@@ -263,7 +264,8 @@ CHERRY_YELLOW, 'image_insert', 'image_edit', 'image_save',
 'add', 'cancel', 'done', 'java', 'mail', 'notes', 'python', 'remove', 'star',
 'terminal', 'terminal-red', 'warning', 'home', 'code', 'html',
 'circle-green', 'circle-grey', 'circle-red', 'circle-yellow',
-'locked', 'unlocked', 'people', 'urgent', 'folder', 'leaf', 'xml', 'c', 'cpp',
+'locked', 'unlocked', 'lockpin', 'people', 'urgent', 'folder', 'leaf',
+'xml', 'c', 'cpp', 'perl',
 ]
 NODES_STOCKS_KEYS = [1,2,3,4,5,6,7,8,9,40,41,42,10,43,11,12,13,14,15,16,44,18,19,20,39,38,21,22,23,24,46,47,48,17,25,26,45,27,28,29,30,31,32,33,34,35,36,37]
 NODES_STOCKS = {
@@ -332,7 +334,10 @@ NODES_ICONS = {
 }
 CODE_ICONS = {
 "python": 'python',
+"python3": 'python',
+"perl": 'perl',
 "sh": 'terminal',
+"dosbatch": 'terminal-red',
 "powershell": 'terminal-red',
 "java": 'java',
 "html": 'html',
@@ -355,7 +360,9 @@ is_richtxt INTEGER,
 has_codebox INTEGER,
 has_table INTEGER,
 has_image INTEGER,
-level INTEGER
+level INTEGER,
+ts_creation INTEGER,
+ts_lastsave INTEGER
 )"""
 
 TABLE_CODEBOX_CREATE = """CREATE TABLE codebox (
